@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2022 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -459,7 +459,7 @@ negbinomial.control <- function(save.weights = FALSE, ...) {
 
 
 
-      newemu <- .emunb
+      newemu <- ( .emunb )
       if ( .lmunb == "nbcanlink") {
         newemu$size <- size.init
       }
@@ -500,7 +500,7 @@ negbinomial.control <- function(save.weights = FALSE, ...) {
 
     munb <- if ( .lmunb == "nbcanlink") {
 
-      newemu <- .emunb
+      newemu <- ( .emunb )
       kmat <- eta2theta(eta[, c(FALSE, TRUE), drop = FALSE],
                         .lsize , earg = .esize )
 
@@ -550,6 +550,7 @@ negbinomial.control <- function(save.weights = FALSE, ...) {
     if (exists("CQO.FastAlgorithm", envir = VGAMenv))
         rm("CQO.FastAlgorithm", envir = VGAMenv)
 
+    newemu <- ( .emunb )
 
     if (function.name == "cao")
       ind2 <- FALSE
@@ -587,7 +588,7 @@ negbinomial.control <- function(save.weights = FALSE, ...) {
   linkfun = eval(substitute(function(mu, extra = NULL) {
     M1 <- 2
 
-    newemu <- .emunb
+    newemu <- ( .emunb )
 
 
     if ( .lmunb == "nbcanlink") {
@@ -919,7 +920,7 @@ negbinomial.control <- function(save.weights = FALSE, ...) {
 
 
       ned2l.dmunb.dsize <- 1 / (munb + kmat)
-      wzoffdiag <- ned2l.dmunb.dsize * dmunb.deta1 * dsize.deta2
+      wzoffdiag <- (munb / kmat) * dsize.deta2  # 20200416
       wz <- if (M > M1) {
         wzoffdiag <- kronecker(wzoffdiag, cbind(1, 0))
         cbind(wz, wzoffdiag[, -ncol(wzoffdiag)])
