@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2022 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -19,11 +19,11 @@ hdeff.vglm <-
            derivative = NULL,
            se.arg = FALSE,
            subset = NULL,  # Useful for Cox model as a poissonff().
+           theta0 = 0,  # Recycled to the necessary length 20210406
            hstep = 0.005,  # Formerly 'Delta', recycled to length 2
            fd.only = FALSE,
            ...) {
 
-
   if (is.Numeric(hstep, positive = TRUE)) {
       if (length(hstep) > 2)
         warning("length(hstep) too large; recycling to 2 values")
@@ -90,12 +90,16 @@ hdeff.vglm <-
   dim.wz <- dim(wwt.0)  # Inefficient
 
   p.VLM <- ncol(all.Hk)
+  if (length(theta0) > p.VLM)
+    warning("length of argument 'theta0' is loo long. ",
+            "Truncating it.")
+  theta0 <- rep_len(theta0, p.VLM)
   M1 <- npred(object, type = "one.response")
 
   vc2 <- vcov(object)
   SE2 <- diag.ixwx <- diag(vc2)
   SE1 <- sqrt(SE2)
-  cobj <- coef(object)
+  cobj <- coef(object) - theta0
   SE2.deriv1 <- vec.Wald.deriv1 <- rep_len(NA_real_, p.VLM)
   names(vec.Wald.deriv1) <- names(cobj)
   if (type == "derivatives" && derivative == 2) {
@@ -168,11 +172,11 @@ hdeff.vglm <-
     if (mixture.links) {
 
 
+
+if (FALSE) {  ###################################################
       myrle <- rle(mylinks)
       if (length(myrle$value) != 2)
         stop("can only handle two types of links in two chunks")
-
- 
       M.1 <- myrle$length[1]
       myearg1 <- object@misc$earg[[1]]
       build.list1 <- list(theta = Param.mat[, 1:(1 + M.1)],
@@ -180,19 +184,79 @@ hdeff.vglm <-
       build.list1 <- c(build.list1, myearg1)  # No dups arg names..
       build.list1$all.derivs <- TRUE  # For "multilogitlink".
       Der11 <- do.call(mylinks[1], build.list1)
-
- 
       M.2 <- 1  # Corresponding to, e.g., loglink("lambda")
       lastone <- length(object@misc$earg)
       tmp5 <- ncol(Param.mat)
       myearg2 <- object@misc$earg[[lastone]]
-
       myearg2$theta <- Param.mat[, (2 + M.1):tmp5]
       myearg2$inverse <- TRUE
       myearg2$deriv <- 1
-
       Der12 <- do.call(mylinks[lastone], myearg2)
       Der1 <- wz.merge(Der11, Der12, M.1, M.2)  # Combine them
+}  # if (FALSE)  ###################################################
+
+
+
+
+  llink <- length(mylinks)  # length(link)
+  vecTF <- mylinks == "multilogitlink"
+  Ans <- NULL  # Growing matrix data structure
+  M.1 <- 0
+  offset.Param.mat <- 0  # Coz rowSums(Param.mat)==1 for multilogitlink
+  iii <- 1
+  while (iii <= llink) {
+    first.index <- last.index <- iii  # Ordinary case
+    special.case <- vecTF[iii]  # && sum(vecTF) < length(vecTF)
+
+    if (special.case) {
+      next.i <- iii+1
+      while (next.i <= llink) {
+        if (vecTF[next.i]) {
+          last.index <- next.i
+          next.i <- next.i + 1
+        } else {
+          break
+        }
+      }  # while
+    }  # special.case
+
+    iii <- iii + last.index - first.index + 1  # For next time
+
+    myearg2 <- object@misc$earg[[first.index]]  # Only one will do
+    if (special.case) {
+      build.list2 <-  # rowSums of Param.mat subset are all == 1:
+        list(theta = Param.mat[, first.index:(last.index+1)],
+             inverse = TRUE, deriv = 1)
+      offset.Param.mat <- offset.Param.mat + 1
+      myearg2 <- c(build.list2, myearg2)  # No dups arg names..
+      myearg2$all.derivs <- TRUE  # For "multilogitlink".
+      myearg2$M <- last.index - first.index  + 1
+    }  # special.case
+
+    use.earg <- myearg2
+    use.earg[["inverse"]] <- TRUE  # New
+    if (!special.case)
+      use.earg[["theta"]] <-
+        Param.mat[, offset.Param.mat + (first.index:last.index)]
+    use.earg$deriv <- 1
+    use.function.name <- mylinks[first.index]  # e.g., "multilogitlink"
+
+    Ans2 <- do.call(use.function.name, use.earg)
+    delete.coln <- FALSE
+    if (special.case && delete.coln)
+      Ans2 <- Ans2[, -use.earg$refLevel]
+
+    M.2 <- last.index - first.index + 1
+    Ans <- if (length(Ans)) wz.merge(Ans, Ans2, M.1, M.2) else Ans2
+    M.1 <- M.1 + M.2
+  }  # while (iii <= llink)
+
+
+
+
+
+
+
     } else {
  # Handle multinomial, etc.
       myearg <- object@misc$earg[[1]]  # Only ONE anyway
@@ -493,6 +557,19 @@ hdeff.vglm <-
     ans <- if (is.matrix(ans))
       ans[kvec.use, , drop = FALSE] else
       ans[kvec.use]
+
+
+  if (any(is.na(ans)) && !fd.only) {
+    warning("NAs detected. Setting 'fd.only = TRUE' and ",
+            "making a full recursive call")
+    ans <- hdeff.vglm(object, derivative = derivative,
+                      se.arg = se.arg, subset = subset,
+                      theta0 = theta0, hstep = hstep,
+                      fd.only = TRUE, ...)
+  }
+
+
+
   ans
 }  # hdeff.vglm
 
@@ -500,14 +577,69 @@ hdeff.vglm <-
 
 
 
- if (!isGeneric("hdeff"))
-    setGeneric("hdeff", function(object, ...) standardGeneric("hdeff"))
+
+
+
+hdeff.matrix <-
+  function(object,
+           ...) {
+  if (!is.matrix(object) || nrow(object) != 2 || ncol(object) != 2) 
+    stop("argument 'object' is not a 2 x 2 matrix")
+  if (any(c(object) <= 0))
+    stop("some cells are not positive valued")
+  is.wholenumber <-
+    function(x, tol = .Machine$double.eps^0.5) abs(x - round(x)) < tol
+  if (!all(is.wholenumber(c(object))))
+    stop("some cells are not integer-valued")
+
+  N0 <- sum(object[1, ])
+  N1 <- sum(object[2, ])
+  p0 <- object[1, 2] / N0
+  p1 <- object[2, 2] / N1
+  oratio <- object[1, 1] * object[2, 2] / (object[1, 2] * object[2, 1])
+  beta2 <- log(oratio)
+  lhs <- 1 + N1 * p1 * (1 - p1) / (N0 * p0 * (1 - p0))
+  rhs <- beta2 * (p1 - 0.5)
+  1 + N1 * p1 * (1 - p1) / (N0 * p0 * (1 - p0)) < beta2 * (p1 - 0.5)
+}  # hdeff.matrix
+
+
+
+
+hdeff.numeric <-
+  function(object,
+           byrow = FALSE,
+           ...) {
+  if (length(c(object)) > 4)
+    stop("length of argument 'object' greater than 4")
+  if (length(c(object)) < 4)
+    warning("length of argument 'object' less than 4, so recycling")
+  hdeff(matrix(c(object), 2, 2, byrow = byrow))  # Recycles if needed
+}  # hdeff.numeric
+
+
+
+
+
+
+
+if (!isGeneric("hdeff"))
+  setGeneric("hdeff", function(object, ...)
+    standardGeneric("hdeff"))
 
 
 setMethod("hdeff", "vglm", function(object, ...)
           hdeff.vglm(object, ...))
 
 
+setMethod("hdeff", "matrix", function(object, ...)
+          hdeff.matrix(object, ...))
+
+setMethod("hdeff", "numeric", function(object, ...)
+          hdeff.numeric(object, ...))
+
+
+
 
 
 
@@ -676,3 +808,5 @@ seglines <-
 
 
 
+
+
